/*
 * This file is part of the XENOMAI project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * Description: Testing XENOMAI services:
 * Shared IRQ
 */

#include <nucleus/xenomai.h>
#include <nucleus/intr.h>

#define SHIRQ_VECTOR	12

xnintr_t intr, intr2;

int shirq_handler(xnintr_t *cookie)
{
    xnarch_logerr("--- shirq_handler() ---\n");

    return XN_ISR_CHAINED;
}

int shirq_handler2(xnintr_t *cookie)
{
    xnarch_logerr("----- shirq_handler2() -----\n");

    return XN_ISR_CHAINED;
}


int __xeno_skin_init (void)

{
    int err;

/* intr */
    xnintr_init(&intr, SHIRQ_VECTOR, &shirq_handler, NULL, XN_ISR_SHARED);
    err = xnintr_attach(&intr, NULL);
    if (err)
	{
	xnarch_logerr("xnintr_attach() failed, err = %i\n", err);
	return 1;
	}

    xnarch_logerr("intr is OK\n");

/* intr2 */
    xnintr_init(&intr2, SHIRQ_VECTOR, &shirq_handler2, NULL, XN_ISR_SHARED);
    err = xnintr_attach(&intr2, NULL);
    if (err)
	{
	xnarch_logerr("xnintr_attach() failed, err = %i\n", err);
	return 1;
	}

    xnarch_logerr("intr2 is OK\n");

    return 0;
}

void __xeno_skin_exit (void)

{
    int err = 0;
    
    xnarch_logerr("let's delete intr\n");

    err = xnintr_detach(&intr);
    if (err)
	xnarch_logerr("xnintr_detach(intr) failed, err = %i\n", err);

    xnarch_logerr("let's delete intr2\n");

    err = xnintr_detach(&intr2);
    if (err)
	xnarch_logerr("xnintr_detach(intr2) failed, err = %i\n", err);

    xnarch_logerr("shirq-module removed\n");
}

module_init(__xeno_skin_init);
module_exit(__xeno_skin_exit);
MODULE_LICENSE("GPL");
